@@ -109,31 +109,14 @@ class Move:
     @ModelView.button
     @Workflow.transition('cancel')
     def cancel(cls, moves):
-        pool = Pool()
-        Date = pool.get('ir.date')
-
-        today = Date.today()
-        for move in moves:
-            move.effective_date = today
-            if (move.from_location.type in ('supplier', 'production')
-                    and move.to_location.type == 'storage'
-                    and move.product.cost_price_method == 'fifo'):
-                move._update_product_cost_price('out')
-            elif (move.to_location.type == 'supplier'
-                    and move.from_location.type == 'storage'
-                    and move.product.cost_price_method == 'fifo'):
-                move._update_product_cost_price('in')
-            move.effective_date = None
-            move.save()
-
-        super(Move, cls).cancel(moves)
+        pass
 
     @classmethod
     def delete(cls, moves):
-        moves = cls.search([
+        fifo_moves = cls.search([
                 ('id', 'in', [m.id for m in moves]),
                 ('fifo_quantity', '!=', 0.0),
                 ])
-        if moves:
-            cls.raise_user_error('del_move_fifo', (moves[0].rec_name,))
+        if fifo_moves:
+            cls.raise_user_error('del_move_fifo', (fifo_moves[0].rec_name,))
         super(Move, cls).delete(moves)
